package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.PoNewsFile;
import com.ruoyi.system.service.IPoNewsFileService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 信息文件Controller
 * @date 2023-01-25
 */
@RestController
@RequestMapping("/system/file")
public class PoNewsFileController extends BaseController
{
    @Autowired
    private IPoNewsFileService poNewsFileService;

    /**
     * 查询信息文件列表
     */
    @ApiOperation("查询信息文件列表")
    @PreAuthorize("@ss.hasPermi('system:file:list')")
    @GetMapping("/list")
    public TableDataInfo list(PoNewsFile poNewsFile)
    {
        startPage();
        List<PoNewsFile> list = poNewsFileService.selectPoNewsFileList(poNewsFile);
        return getDataTable(list);
    }

    /**
     * 导出信息文件列表
     */
    @ApiOperation("导出信息文件列表")
    @PreAuthorize("@ss.hasPermi('system:file:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PoNewsFile poNewsFile)
    {
        List<PoNewsFile> list = poNewsFileService.selectPoNewsFileList(poNewsFile);
        ExcelUtil<PoNewsFile> util = new ExcelUtil<PoNewsFile>(PoNewsFile.class);
        util.exportExcel(response, list, "信息文件数据");
    }

    /**
     * 获取信息文件详细信息
     */
    @ApiOperation("获取信息文件详细信息")
    @PreAuthorize("@ss.hasPermi('system:file:query')")
    @GetMapping(value = "/{fileId}")
    public AjaxResult getInfo(@PathVariable("fileId") Long fileId)
    {
        return success(poNewsFileService.selectPoNewsFileByFileId(fileId));
    }

    /**
     * 新增信息文件
     */
    @ApiOperation("新增信息文件")
    @PreAuthorize("@ss.hasPermi('system:file:add')")
    @Log(title = "信息文件", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PoNewsFile poNewsFile)
    {
        return toAjax(poNewsFileService.insertPoNewsFile(poNewsFile));
    }

    /**
     * 修改信息文件
     */
    @ApiOperation("修改信息文件")
    @PreAuthorize("@ss.hasPermi('system:file:edit')")
    @Log(title = "信息文件", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PoNewsFile poNewsFile)
    {
        return toAjax(poNewsFileService.updatePoNewsFile(poNewsFile));
    }

    /**
     * 删除信息文件
     */
    @ApiOperation("删除信息文件")
    @PreAuthorize("@ss.hasPermi('system:file:remove')")
    @Log(title = "信息文件", businessType = BusinessType.DELETE)
    @DeleteMapping("/{fileIds}")
    public AjaxResult remove(@PathVariable Long[] fileIds)
    {
        return toAjax(poNewsFileService.deletePoNewsFileByFileIds(fileIds));
    }
}
